@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -155,17 +155,17 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 160 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 160 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", false);
-//@line 164 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 164 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 182 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 182 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 185 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -513,9 +513,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 533 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 533 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 535 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -560,9 +560,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 580 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 580 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 582 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 582 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -693,6 +693,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -711,6 +712,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -719,6 +721,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -726,6 +730,8 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
 pref("network.IDN.whitelist.xn--p1ai", true);
 // sa, Saudi Arabia, .<al-Saudiah> with variants
@@ -823,7 +829,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 848 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 854 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -842,9 +848,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 873 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 879 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  0);
-//@line 875 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 881 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1206,9 +1212,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1615 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1621 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1617 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1623 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1622,21 +1628,21 @@ pref("print.print_extra_margin", 90); // twips (90 twips is an eigth of an inch)
 // See bug 404131, topmost <panel> element wins to Dashboard on MacOSX.
 pref("ui.panel.default_level_parent", false);
 
-//@line 2032 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2038 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2233 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2239 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2327 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2333 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2600 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2606 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2668 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2674 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2694 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2700 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2714 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2720 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2722 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2728 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1660,7 +1666,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2751 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2757 "/builds/slave/191-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
