@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/builds/slave/191-osx-xr/build/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -165,7 +165,7 @@ var InlineSpellCheckerUI = {
 
     for (var i = 0; i < list.length; i ++) {
       // get the display name for this dictionary
-      isoStrArray = list[i].split("-");
+      isoStrArray = list[i].split(/[-_]/);
       var displayName = "";
       if (this.mLanguageBundle && isoStrArray[0]) {
         try {
@@ -186,6 +186,7 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
+      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
